Enum Type
#[non_exhaustive]#[repr(u32)]pub enum Type {
Pen = 320,
Eraser = 321,
Brush = 322,
Pencil = 323,
Airbrush = 324,
Finger = 325,
Mouse = 326,
Lens = 327,
}Available on crate feature
wayland and Linux only.Expand description
a physical tool type
Describes the physical type of a tool. The physical type of a tool generally defines its base usage.
The mouse tool represents a mouse-shaped tool that is not a relative device but bound to the tablet’s surface, providing absolute coordinates.
The lens tool is a mouse-shaped tool with an attached lens to provide precision focus.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pen = 320
Pen
Eraser = 321
Eraser
Brush = 322
Brush
Pencil = 323
Pencil
Airbrush = 324
Airbrush
Finger = 325
Finger
Mouse = 326
Mouse
Lens = 327
Lens